==> apache-hop-2.1.0-src.tar.gz: apache-hop-2.1.0/core/src/test/java/org/apache/hop/core/extension/ExtensionPointHandlerTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hop.core.extension;

import org.apache.hop.core.logging.ILogChannel;
import org.apache.hop.core.plugins.PluginRegistry;
import org.apache.hop.junit.rules.RestoreHopEnvironment;
import org.junit.ClassRule;
import org.junit.Test;

import static org.mockito.Matchers.*;
import static org.mockito.Mockito.*;

public class ExtensionPointHandlerTest {
  @ClassRule public static RestoreHopEnvironment env = new RestoreHopEnvironment();
  private static final String TEST_NAME = "testName";

  @Test
  public void callExtensionPointTest() throws Exception {
    IPluginMock pluginInterface = mock(IPluginMock.class);
    when(pluginInterface.getName()).thenReturn(TEST_NAME);
    when(pluginInterface.getMainType()).thenReturn((Class) IExtensionPoint.class);
    when(pluginInterface.getIds()).thenReturn(new String[] {"testID"});

    IExtensionPoint extensionPoint = mock(IExtensionPoint.class);
    when(pluginInterface.loadClass(IExtensionPoint.class)).thenReturn(extensionPoint);

    PluginRegistry.addPluginType(ExtensionPointPluginType.getInstance());
    PluginRegistry.getInstance().registerPlugin(ExtensionPointPluginType.class, pluginInterface);

    final ILogChannel log = mock(ILogChannel.class);

    ExtensionPointHandler.callExtensionPoint(log, null, "noPoint", null);
    verify(extensionPoint, never()).callExtensionPoint(any(ILogChannel.class), any(), any());

    ExtensionPointHandler.callExtensionPoint(log, null, TEST_NAME, null);
    verify(extensionPoint, times(1)).callExtensionPoint(eq(log), any(), isNull());
  }
}

==> apache-hop-2.6.0-src.tar.gz: apache-hop-2.6.0/core/src/test/java/org/apache/hop/core/extension/ExtensionPointHandlerTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hop.core.extension;

import org.apache.hop.core.logging.ILogChannel;
import org.apache.hop.core.plugins.PluginRegistry;
import org.apache.hop.junit.rules.RestoreHopEnvironment;
import org.junit.ClassRule;
import org.junit.Test;

import static org.mockito.Matchers.any;
import static org.mockito.Matchers.eq;
import static org.mockito.Matchers.isNull;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.never;
import static org.mockito.Mockito.times;
import static org.mockito.Mockito.verify;
import static org.mockito.Mockito.when;

public class ExtensionPointHandlerTest {
  @ClassRule public static RestoreHopEnvironment env = new RestoreHopEnvironment();
  private static final String TEST_NAME = "testName";

  @Test
  public void callExtensionPointTest() throws Exception {
    IPluginMock pluginInterface = mock(IPluginMock.class);
    when(pluginInterface.getName()).thenReturn(TEST_NAME);
    when(pluginInterface.getMainType()).thenReturn((Class) IExtensionPoint.class);
    when(pluginInterface.getIds()).thenReturn(new String[] {"testID"});

    IExtensionPoint extensionPoint = mock(IExtensionPoint.class);
    when(pluginInterface.loadClass(IExtensionPoint.class)).thenReturn(extensionPoint);

    PluginRegistry.addPluginType(ExtensionPointPluginType.getInstance());
    PluginRegistry.getInstance().registerPlugin(ExtensionPointPluginType.class, pluginInterface);

    final ILogChannel log = mock(ILogChannel.class);

    ExtensionPointHandler.callExtensionPoint(log, null, "noPoint", null);
    verify(extensionPoint, never()).callExtensionPoint(any(ILogChannel.class), any(), any());

    ExtensionPointHandler.callExtensionPoint(log, null, TEST_NAME, null);
    verify(extensionPoint, times(1)).callExtensionPoint(eq(log), any(), isNull());
  }
}
